"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const fs = require("fs-extra");
const command_1 = require("@oclif/command");
const server = require('@tru_id/dev-server');
class Serve extends command_1.Command {
    async run() {
        const { flags } = this.parse(Serve);
        const projectConfig = await this.loadProjectConfig(flags);
        server.serve({
            port: flags.port,
            localtunnel: {
                enabled: flags.localtunnel,
                subdomain: flags['localtunnel-subdomain'],
            },
            project: {
                client_id: projectConfig.credentials[0].client_id,
                client_secret: projectConfig.credentials[0].client_secret,
            },
        });
    }
    // TODO share with @tru_id/cli
    async loadProjectConfig(flags) {
        var _a;
        const projectDirectory = (_a = flags['project-dir']) !== null && _a !== void 0 ? _a : process.cwd();
        const projectConfigFullPath = path.join(projectDirectory, 'tru.json');
        const projectConfigExists = fs.existsSync(projectConfigFullPath);
        if (projectConfigExists === false) {
            this.log(`A project configuration file does not exist at "${projectConfigFullPath}".\n` +
                'Please provide a valid directory path using the `--project-dir` flag or run `tru projects:create` to create a project and associated configuration file.');
            this.exit(1);
        }
        try {
            return await fs.readJson(projectConfigFullPath);
        }
        catch (error) {
            this.log('There was a problem loading the tru.json configuration file', `${error.toString()} ${JSON.stringify(error)}`);
            this.exit(1);
        }
    }
}
exports.default = Serve;
Serve.description = 'Runs a development server from the CLI';
Serve.examples = [
    `$ tru server
`,
    `$ tru server -t -p 4000
`,
];
Serve.flags = {
    help: command_1.flags.help({ char: 'h' }),
    localtunnel: command_1.flags.boolean({
        description: 'Run a localtunnel to expose the server to the Internet',
        char: 't',
        default: false,
    }),
    'localtunnel-subdomain': command_1.flags.string({
        description: 'The subdomain for the local tunnel',
        char: 's',
    }),
    // TODO share with @tru_id/cli
    'project-dir': command_1.flags.string({
        description: 'The directory that contains the tru.json Project configuration file',
        default: '.',
    }),
    port: command_1.flags.integer({
        description: 'The port the server should listen on',
        char: 'p',
        default: 8080,
    }),
};
